@@ -35,14 +35,14 @@ extern "C" {
 }
 
 #[inline(always)]
-pub unsafe fn PyUnicode_Check(op : *mut PyObject) -> bool {
+pub unsafe fn PyUnicode_Check(op : *mut PyObject) -> c_int {
     PyType_FastSubclass(Py_TYPE(op), Py_TPFLAGS_UNICODE_SUBCLASS)
 }
 
 #[inline(always)]
-pub unsafe fn PyUnicode_CheckExact(op : *mut PyObject) -> bool {
+pub unsafe fn PyUnicode_CheckExact(op : *mut PyObject) -> c_int {
     let u : *mut PyTypeObject = &mut PyUnicode_Type;
-    Py_TYPE(op) == u
+    (Py_TYPE(op) == u) as c_int
 }
 
 #[inline(always)]
